@@ -395,26 +395,6 @@ namespace orc {
     ASSERT_TRUE(!result->Next(&ptr, &length));
   }
 
-  TEST_F(TestDecompression, testLzoOverflow) {
-    const unsigned char bad_lzo_data[] = {// Header: compressedSize = 12, original = false
-                                          0x18, 0x00, 0x00,
-
-                                          // LZO body: token and literal length extension
-                                          0x00,  // token: extended literal length
-                                          0xFF,  // extension byte 1
-
-                                          // Literal data: only 10 bytes far less than 273
-                                          'A', 'A', 'A', 'A', 'A', 'A', 'A', 'A', 'A', 'A'};
-
-    std::unique_ptr<SeekableInputStream> result = createDecompressor(
-        CompressionKind_LZO,
-        std::make_unique<SeekableArrayInputStream>(bad_lzo_data, ARRAY_SIZE(bad_lzo_data)),
-        128 * 1024, *getDefaultPool(), getDefaultReaderMetrics());
-    const void* ptr;
-    int length;
-    EXPECT_THROW(result->Next(&ptr, &length), ParseError);
-  }
-
   TEST_F(TestDecompression, testLz4Empty) {
     const unsigned char buffer[] = {0};
     std::unique_ptr<SeekableInputStream> result = createDecompressor(
@@ -565,7 +545,7 @@ namespace orc {
         *getDefaultPool(), getDefaultReaderMetrics());
     const void* ptr;
     int length;
-    ASSERT_THROW(result->BackUp(20), std::logic_error);
+    ASSERT_THROW(result->BackUp(20), CompressionError);
     ASSERT_EQ(true, result->Next(&ptr, &length));
     ASSERT_EQ(30, length);
     for (int i = 0; i < 10; ++i) {
@@ -574,7 +554,7 @@ namespace orc {
       }
     }
     result->BackUp(10);
-    ASSERT_THROW(result->BackUp(2), std::logic_error);
+    ASSERT_THROW(result->BackUp(2), CompressionError);
     ASSERT_EQ(true, result->Next(&ptr, &length));
     ASSERT_EQ(10, length);
     for (int i = 0; i < 10; ++i) {
@@ -621,33 +601,33 @@ namespace orc {
 #define HEADER_SIZE 3
 
   class CompressBuffer {
-    std::vector<char> buf;
+    std::vector<char> buf_;
 
    public:
-    CompressBuffer(size_t capacity) : buf(capacity + HEADER_SIZE) {}
+    CompressBuffer(size_t capacity) : buf_(capacity + HEADER_SIZE) {}
 
     char* getCompressed() {
-      return buf.data() + HEADER_SIZE;
+      return buf_.data() + HEADER_SIZE;
     }
     char* getBuffer() {
-      return buf.data();
+      return buf_.data();
     }
 
     void writeHeader(size_t compressedSize) {
-      buf[0] = static_cast<char>(compressedSize << 1);
-      buf[1] = static_cast<char>(compressedSize >> 7);
-      buf[2] = static_cast<char>(compressedSize >> 15);
+      buf_[0] = static_cast<char>(compressedSize << 1);
+      buf_[1] = static_cast<char>(compressedSize >> 7);
+      buf_[2] = static_cast<char>(compressedSize >> 15);
     }
 
     void writeUncompressedHeader(size_t compressedSize) {
       writeHeader(compressedSize);
-      buf[0] |= 1;
+      buf_[0] |= 1;
     }
 
     size_t getCompressedSize() const {
-      size_t header = static_cast<unsigned char>(buf[0]);
-      header |= static_cast<size_t>(static_cast<unsigned char>(buf[1])) << 8;
-      header |= static_cast<size_t>(static_cast<unsigned char>(buf[2])) << 16;
+      size_t header = static_cast<unsigned char>(buf_[0]);
+      header |= static_cast<size_t>(static_cast<unsigned char>(buf_[1])) << 8;
+      header |= static_cast<size_t>(static_cast<unsigned char>(buf_[2])) << 16;
       return header >> 1;
     }
 
